@@ -18,21 +18,33 @@
  *   along with TabletToolbox.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <config.h>
+
 #include <stdio.h>
+#include <libintl.h>
+#include "ttb-app.h"
 #include "ttb-base.h"
 #include "ui-gtk.h"
+#include "ttb-paths.h"
 
 int main(int argc, char **argv)
 {
+	TTBApp *app;
+
 	g_type_init();
 
-	TTBBase *base = g_object_new(TTB_TYPE_BASE, NULL);
-	TTBUI *ui = g_object_new(UI_TYPE_GTK, "base", base, NULL);
+	#ifdef ENABLE_NLS
+        /* Setting up gettext */
+        bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
+        textdomain(GETTEXT_PACKAGE);
+        #endif /* ENABLE_NLS */
 
-	TTB_UI_GET_CLASS(ui)->exec(ui, argc, argv);
+	app = g_object_new(TTB_TYPE_APP, NULL);
+
+	ttb_app_exec(app, argc, argv);
+
+	g_object_unref(app);
 
-	g_object_unref(ui);
-	g_object_unref(base);
 	return 1;
 }
 
